R/data.R
am_hcaf.RdHalf degree cell location reference data This table represents an authority file with reference data for half degree cell locations.
am_hcaf()Other general:
am_hspen(),
am_search_exact(),
am_search_fuzzy(),
download_db()
if (FALSE) { # \dontrun{
am_hcaf()
} # }