Raster with native habitat map data for one or several species
am_raster(key, resolution = 0.5, fun = c("count", "last", "first"))if the fun parameter is omitted, the probability field will be used
if (FALSE) { # \dontrun{
ras <- am_raster(am_search_fuzzy("trevally")$key)
} # }