Given a set of grid cell identifiers or CsquareCodes, this function returns a list of the species that occur there
am_species_in_csc(csc, min_prob = 0.5)if (FALSE) { # \dontrun{
# distinct number of species in a specific grid cell
am_species_in_csc("7516:236:1", 0.99)
# other species likely present in the same area as the bluespotted trevally
xt <- am_raster(am_search_fuzzy("bluespotted trevally")$key)@extent
csc <- am_csc_from_extent(xt@xmin, xt@xmax, xt@ymin, xt@ymax)$CsquareCode
am_species_in_csc(csc, min_prob = 0.9)
} # }