R/spatial.R
rasterize_coords.Rd
Converts location coordinate data into raster data
rasterize_coords(lon, lat, fun = "count")
decimal longitude for coordinates
decimal latitude for coordinates
aggregation method when several points occur in one cell
a raster grid with individual cell values representing the count of occurrences within the grid cells using WGS84
Other spatial: am_csc_from_extent(), am_map_leaflet(), am_raster(), am_species_in_csc(), am_species_per_csc(), csquare_from_dd(), csquare_to_dd(), which_cells_in_raster()
am_csc_from_extent()
am_map_leaflet()
am_raster()
am_species_in_csc()
am_species_per_csc()
csquare_from_dd()
csquare_to_dd()
which_cells_in_raster()