Search taxonomic names with or without parameters specified.
If parameters are given, the intersection of matching records are returned.
If no parameters are given, all records are returned.
If parameters are specified with NULL specified, examples of valid combinations of values are returned.
am_search_exact(
SpeciesID = NULL,
SpecCode = NULL,
Genus = NULL,
Species = NULL,
FBname = NULL,
OccurRecs = NULL,
OccurCells = NULL,
StockDefs = NULL,
Kingdom = NULL,
Phylum = NULL,
Class = NULL,
Order = NULL,
Family = NULL,
deepwater = NULL,
angling = NULL,
diving = NULL,
dangerous = NULL,
m_invertebrates = NULL,
highseas = NULL,
invasive = NULL,
resilience = NULL,
iucn_id = NULL,
iucn_code = NULL,
iucn_version = NULL,
provider = NULL
)AquaMaps unique identifier for a valid species used by the Catalogue of Life Annual Checklist (www.catalogueoflife.org). Example for the whale shark: Fis-30583
Species identifier used in FishBase or SeaLifeBase
Genus name of the species
Specific epithet of the species
Common name suggested by FishBase or SeaLifeBase
Number of point records used to generate good cells
Number of good cells used to generate species envelope
Distribution of the species as recorded in FishBase or SeaLifeBase
Kingdom to which the species belongs
Phylum to which the species belongs
Class to which the species belongs
Order to which the species belongs
Family to which the species belongs
Does the species occur in the deep-sea (i.e. tagged bathypelagic or bathydemersal in FishBase or SeaLifeBase)? 0=No, 1=Yes
Is the species a sport fish (i.e. tagged as a GameFish in FishBase)? 0=No, 1=Yes
Is the species found on a dive (i.e. where DepthPrefMin in HSPEN < 20 meters)? 0=No, 1=Yes
Is the species dangerous (i.e. tagged as traumatogenic or venonous in FishBase or SeaLifeBase)? 0=No, 1=Yes
Is the species a marine invertebrate? 0=No, 1=Yes
Is the species an open ocean fish species (i.e. tagged as pelagic-oceanic in FishBase)? 0=No, 1=Yes
Is the species recorded to be invasive (i.e. in FishBase or SeaLifeBase)? 0=No, 1=Yes
Resilience of the species (i.e. as recorded in FishBase/SeaLifeBase)
IUCN species identifier
IUCN Red list classification assigned to the species
IUCN version
FishBase (FB) or SeaLifeBase (SLB)?
tibble with results...
Other general:
am_hcaf(),
am_hspen(),
am_search_fuzzy(),
download_db()
if (FALSE) { # \dontrun{
am_search_exact()
am_search_exact(Species = "bucculentus")
am_search_exact(FBname = NULL, provider = NULL)
} # }